@@ -14,8 +14,8 @@ from .core import config, agent
 from .core.agent import Agent
 from .core.env import Env
 from .systems.achievement import Task
-from .core.terrain import MapGenerator
+from .core.terrain import MapGenerator, Terrain
 
-__all__ = ['Env', 'config', 'scripting', 'agent', 'Agent', 'MapGenerator',
+__all__ = ['Env', 'config', 'scripting', 'agent', 'Agent', 'MapGenerator', 'Terrain',
         'Serialized', 'action', 'Action', 'scripting', 'material',
         'Task', 'Overlay', 'OverlayRegistry']
